(function ($, Drupal, drupalSettings) {
  'use strict';

  Drupal.behaviors.mp2 = {
    attach: function (context, settings) {
      var card = new Card({
        // a selector or DOM element for the form where users will
        // be entering their information
        form: '.commerce-checkout-flow',
        // a selector or DOM element for the container
        // where you want the card to appear
        container: '.card-wrapper',
        formSelectors: {
          numberInput: 'input#edit-card-number',
          expiryInput: 'input#edit-expiry-date',
          cvcInput: 'input#edit-card-security-code',
          nameInput: 'input#edit-card-holder-name'
        },
        formatting: true,
        // Strings for translation - optional
        messages: {
          validDate: 'valid\ndate',
          monthYear: 'mm/yy'
        },
        // Default placeholders for rendered fields - optional
        placeholders: {
          number: '•••• •••• •••• ••••',
          name: 'Full Name',
          expiry: '••/••',
          cvc: '•••'
        },
        masks: {
          cardNumber: '•'
        },
      });

      // Change form values so they work with Payfort API.
      $('.commerce-checkout-flow', context).submit(function(e) {
        var expDateArr = $(this).find('#edit-expiry-date').val().split('/');
        $(this).find('#edit-expiry-date').val(expDateArr[1].trim() + expDateArr[0].trim());
        var cardNumber = $(this).find('#edit-card-number').val();
        $(this).find('#edit-card-number').val(cardNumber.replace(/\s/g, ''));
        if (settings.commerce_payfort.device_fingerprint) {
          $.ajax({
            url: settings.commerce_payfort.fingerprint_url,
            type: 'POST',
            data: {device_fingerprint: $(this).find('#device_fingerprint').val()},
            async: false,
            success: function(data, textStatus, jQxhr) {
              if(data){
                $('#device_fingerprint').remove();
              }
            }
          });
        }
        return true;
      });
    }
  };

})(jQuery, Drupal, drupalSettings);